@@ -7,4 +7,8 @@ class ParseError(Exception):
         Raises with an informative error about the format string
         """
         error_str = f"Could not parse table row.\nExpected Format: {format}\nGot String: {input}"
-        raise cls(error_str)
\ No newline at end of file
+        raise cls(error_str)
+
+
+class ResolutionError(Exception):
+    """Could not resolve a dependency!"""
\ No newline at end of file
